Skip to main contentModule model
Source - Attachment
- Avatar
- Ban
- Channel
- ChannelMention
- ClientStatus
- CreateMessage
- Builder for creating Discord messages with embeds, replies, etc.
- Embed
- EmbedAuthor
- EmbedBuilder
- Fluent builder for creating Discord embeds.
- EmbedField
- EmbedFooter
- EmbedImage
- EmbedProvider
- EmbedThumbnail
- EmbedVideo
- Emoji
- ForumTag
- Guild
- Interaction
- Member
- MergedMember
- Message
- MessageActivity
- Nameplate
- PassiveChannelState
- PassiveUpdateV1
- PASSIVE_UPDATE_V1 payload.
- PermissionOverwrite
- Permissions
- Poll
- Presence
- Reaction
- ReadStateContainer
- ReadStateEntry
- ReadySupplemental
- READY_SUPPLEMENTAL payload.
- Relationship
- Represents a relationship between the current user and another user (e.g., friend, blocked, etc.)
- Role
- RoleColors
- RoleTags
- Sticker
- SupplementalMember
- SupplementalMessageRequest
- ThreadMember
- User
- UserProfile
- ChannelType
- Represents a Discord channel (text, voice, DM, etc.)
- MessageType
- PermissionOverwriteType
- RelationshipType
- Represents the type of relationship between the current user and another user (e.g., friend, blocked, etc.)